@@ -82,7 +82,7 @@ use Log::Fine::Levels;
 use Log::Fine::Logger;
 use POSIX qw( strftime );
 
-our $VERSION = '0.36';
+our $VERSION = '0.37';
 
 =head2 Formatters
 
@@ -391,9 +391,20 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =back
 
+=head1 CONTRIBUTING
+
+Want to contribute?  The source code repository for Log::Fine is now
+available at L<http://github.com/cfuhrman/log-fine>.  To clone your
+own copy:
+
+  $ git clone git://github.com/cfuhrman/log-fine.git
+
+Signed patches generated by L<git-format-patch>(1) may be submitted
+L<via email|/AUTHOR>.
+
 =head1 REVISION INFORMATION
 
-  $Id: f5a07acd9d00ed0111a48e8816aa5ee1bf559545 $
+  $Id: 3cdb9b7f8436503e5cc78247cdb183280ff73b5a $
 
 =head1 COPYRIGHT & LICENSE
 
